plugin

package
v0.10.8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 19, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DefaultPluginDir

func DefaultPluginDir() (string, error)

DefaultPluginDir returns ~/.ai-happy-design/plugin.

func ExtractTo

func ExtractTo(dir, version string) error

ExtractTo writes the embedded plugin files to dir and stamps .version.

func NeedsUpdate

func NeedsUpdate(dir, version string) bool

NeedsUpdate returns true if the plugin at dir is missing or has a different version.

Types

This section is empty.

Jump to